@@ -22,7 +22,6 @@ class TalosClientConfig:
     _maxTotalConnectionsPerRoute = int
     _isRetry = bool
     _isAutoLocation = bool
-    _isOpenDnsResolver = bool
     _scheduleInfoMaxRetry = int
     _updateScheduleInfoInterval = int
     _falconUrl = str
@@ -33,7 +32,6 @@ class TalosClientConfig:
     _metricFalconStep = int
     _alertType = str
     _clusterName = str
-    _scheduleInfoMaxRetry = int
 
     # producer configs
     _service_endpoint = str
@@ -42,7 +40,6 @@ class TalosClientConfig:
     _maxBufferedMsgTime = int
     _maxPutMsgNumber = int
     _maxPutMsgBytes = int
-    _maxSingleMessageBytes = int
     _producerCheckPartitionInterval = int
     # put failed related private
     _maxRetryTimes = int
@@ -90,9 +87,9 @@ class TalosClientConfig:
             TalosClientConfigKeys.GALAXY_TALOS_DEFAULT_SERVICE_ENDPOINT)
         if not self._serviceEndpint:
             raise RuntimeError("The property of 'galaxy.talos.service.endpoint' must be set")
-        self._clusterName = self.get_service_endpoint().replace("http://", "") \
-            .replace("https://", "") \
-            .replace(".api.xiaomi.net", "") \
+        self._clusterName = self.get_service_endpoint().replace("http://", "")\
+            .replace("https://", "")\
+            .replace(".api.xiaomi.net", "")\
             .replace(".api.xiaomi.com", "")
         self._secureServiceEndpint = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_SECURE_SERVICE_ENDPOINT,
@@ -109,9 +106,6 @@ class TalosClientConfig:
         self._isAutoLocation = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_AUTO_LOCATION,
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_AUTO_LOCATION_DEFAULT)
-        self._isOpenDnsResolver = pro.get(
-            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_OPEN_DNS_RESOLVER,
-            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_IS_OPEN_DNS_RESOLVER_DEFAULT)
         self._scheduleInfoMaxRetry = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY,
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY_DEFAULT)
@@ -142,9 +136,6 @@ class TalosClientConfig:
         self._alertType = pro.get(
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_ALERT_TYPE,
             TalosClientConfigKeys.GALAXY_TALOS_CLIENT_ALERT_TYPE_DEFAULT)
-        self._scheduleInfoMaxRetry = pro.get(
-            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY,
-            TalosClientConfigKeys.GALAXY_TALOS_CLIENT_SCHEDULE_INFO_MAX_RETRY_DEFAULT)
 
         self._maxBufferedMsgNumber = pro.get(
             TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_MAX_BUFFERED_MESSAGE_NUMBER,
@@ -247,9 +238,6 @@ class TalosClientConfig:
         self._putMessageMaxFailedTimes = pro.get(
             TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_PUT_MESSAGE_MAX_FAILED_TIMES,
             TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_PUT_MESSAGE_MAX_FAILED_TIMES_DEFAULT)
-        self._maxSingleMessageBytes = pro.get(
-            TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES,
-            TalosProducerConfigKeys.GALAXY_TALOS_PRODUCER_MAX_SINGLE_MESSAGE_BYTES_DEFAULT)
 
     def get_max_retry(self):
         return self._maxRetry
@@ -281,9 +269,6 @@ class TalosClientConfig:
     def get_is_auto_location(self):
         return self._isAutoLocation
 
-    def get_is_open_dns_resolver(self):
-        return self._isOpenDnsResolver
-
     def get_schedule_info_max_retry(self):
         return self._scheduleInfoMaxRetry
 
@@ -321,9 +306,6 @@ class TalosClientConfig:
     def get_max_put_msg_bytes(self):
         return self._maxPutMsgBytes
 
-    def get_max_single_msg_bytes(self):
-        return self._maxSingleMessageBytes
-
     def get_thread_pool_size(self):
         return self._threadPoolSize
 
@@ -413,8 +395,3 @@ class TalosClientConfig:
 
     def get_cluster_name(self):
         return self._clusterName
-
-    def get_schedule_info_max_retry(self):
-        return self._scheduleInfoMaxRetry
-
-
