@@ -22,10 +22,7 @@ class FalconWriter(object):
 
 	def push_falcon_data(self, falconData=None):
 		try:
-			logger.debug("falconUrl: " + self.falconUrl)
-			logger.debug("data: " + str(falconData))
 			resp = requests.post(self.falconUrl, json=falconData, headers=self.headers)
-			logger.debug("resp: " + str(resp))
 			if not resp.status_code == 200:
 				logger.error("Post data failed, StatusCode: " + str(resp.status_code))
 		except Exception as throwable:
